@@ -1,6 +1,6 @@
 import os
 
-__name__ ='pygwbl'
+# __name__ ='pygwbl'
 __all__=["svg2emf","about"]
 
 
